Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(613)

Unified Diff: third_party/WebKit/Source/core/layout/svg/LayoutSVGResourceMarker.cpp

Issue 2465983002: Rename "paint invalidation rect" etc. to "visual rect". (Closed)
Patch Set: - Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/layout/svg/LayoutSVGResourceMarker.cpp
diff --git a/third_party/WebKit/Source/core/layout/svg/LayoutSVGResourceMarker.cpp b/third_party/WebKit/Source/core/layout/svg/LayoutSVGResourceMarker.cpp
index acee522aeee918b7a1e813de2872cb9e00f1a8a4..a1b5d8d38b837ef41695618d074a7a604b1c9361 100644
--- a/third_party/WebKit/Source/core/layout/svg/LayoutSVGResourceMarker.cpp
+++ b/third_party/WebKit/Source/core/layout/svg/LayoutSVGResourceMarker.cpp
@@ -63,11 +63,10 @@ void LayoutSVGResourceMarker::removeClientFromCache(LayoutObject* client,
FloatRect LayoutSVGResourceMarker::markerBoundaries(
const AffineTransform& markerTransformation) const {
- FloatRect coordinates =
- LayoutSVGContainer::paintInvalidationRectInLocalSVGCoordinates();
+ FloatRect coordinates = LayoutSVGContainer::visualRectInLocalSVGCoordinates();
- // Map paint invalidation rect into parent coordinate space, in which the
- // marker boundaries have to be evaluated.
+ // Map visual rect into parent coordinate space, in which the marker
+ // boundaries have to be evaluated.
coordinates = localToSVGParentTransform().mapRect(coordinates);
return markerTransformation.mapRect(coordinates);

Powered by Google App Engine
This is Rietveld 408576698